# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-06 14:55
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('csp_report', '0002_cleanedcspreport'),
    ]

    operations = [
        migrations.CreateModel(
            name='CSPReportFilter',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('filter_type', models.TextField()),
                ('value', models.TextField()),
                ('is_enabled', models.BooleanField(default=True)),
            ],
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-06 13:49
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('csp_report', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='CleanedCSPReport',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('document_scheme', models.TextField(blank=True, default='', null=True)),
                ('document_domain', models.TextField(blank=True, default='', null=True)),
                ('document_path', models.TextField(blank=True, default='', null=True)),
                ('document_query', models.TextField(blank=True, default='', null=True)),
                ('blocked_domain', models.TextField(blank=True, default='', null=True)),
                ('blocked_url', models.TextField(blank=True, default='', null=True)),
                ('report', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='csp_report.CSPReport')),
            ],
        ),
    ]
